@@ -8,21 +8,20 @@ from core_main_app.commons.enums import WEB_PAGE_TYPES
 
 
 class WebPage(Document):
-    """ Represents a WebPage
-    """
+    """Represents a WebPage"""
 
     type = fields.IntField()
     content = fields.StringField()
 
     @staticmethod
     def get_by_type(page_type):
-        """ Get a WebPage given its type
+        """Get a WebPage given its type
 
-            Parameters:
-                page_type (str): page type
+        Parameters:
+            page_type (str): page type
 
-            Returns:
-                Web Page corresponding to the given type
+        Returns:
+            Web Page corresponding to the given type
         """
         try:
             return WebPage.objects.get(type=WEB_PAGE_TYPES[page_type])
@@ -33,7 +32,7 @@ class WebPage(Document):
 
     @staticmethod
     def delete_by_type(page_type_key):
-        """ Delete all WebPage with the given type key
+        """Delete all WebPage with the given type key
 
         Args:
             page_type_key (int): page type key
