@@ -444,7 +444,7 @@ let actionButtonClicked = function(migrate) {
         error: (error) => {
             jqError.html('Impossible to start the ' +
                 (migrate ? 'migration' : 'validation') +
-                ' task :' + JSON.stringify(error));
+                ' task :' + (error.responseText ? error.responseText : JSON.stringify(error)));
             jqError.show();
         }
     });
@@ -567,7 +567,7 @@ let displaySummary = function(taskData, migrate) {
                             'View error' +
                         '</button>' +
                         '<div id="error-list" class="hidden"><h4>Failed data files:</h4>' +
-                        '<ul class="list-group list-group-flush">';
+                        '<ul class="error-container list-group list-group-flush">';
 
                     taskData.details.wrong.forEach((dataId) => {
                         failedButtonHtml += '<li class="list-group-item"><a href="/admin/data?id=' + dataId + '">' +
