@@ -27,11 +27,13 @@ from core_main_app.utils.labels import get_data_label
 from core_main_app.utils.rendering import admin_render
 from core_main_app.utils.rendering import render
 from core_main_app.views.admin.forms import UploadXSLTForm, TemplateXsltRenderingForm
+from bson import ObjectId
+from core_main_app.utils.view_builders import data as data_view_builder
 
 
 class CommonView(View, metaclass=ABCMeta):
     """
-        Abstract common view for admin and user.
+    Abstract common view for admin and user.
     """
 
     administration = False
@@ -51,7 +53,7 @@ class CommonView(View, metaclass=ABCMeta):
 
 class EditWorkspaceRights(CommonView):
     """
-        Edit workspace rights
+    Edit workspace rights
     """
 
     template = "core_main_app/user/workspaces/edit_rights.html"
@@ -190,7 +192,7 @@ class EditWorkspaceRights(CommonView):
 
 class ViewData(CommonView):
     """
-        View detail data.
+    View detail data.
     """
 
     template = "core_main_app/user/data/detail.html"
@@ -199,55 +201,11 @@ class ViewData(CommonView):
         data_id = request.GET["id"]
 
         try:
-            data = data_api.get_by_id(data_id, request.user)
+            data_object = data_api.get_by_id(data_id, request.user)
+            page_context = data_view_builder.build_page(data_object)
 
-            context = {"data": data, "share_pid_button": False}
-
-            assets = {
-                "js": [
-                    {"path": "core_main_app/common/js/XMLTree.js", "is_raw": False},
-                    {"path": "core_main_app/user/js/data/detail.js", "is_raw": False},
-                ],
-                "css": ["core_main_app/common/css/XMLTree.css"],
-            }
-
-            modals = []
-
-            if "core_file_preview_app" in INSTALLED_APPS:
-                assets["js"].extend(
-                    [
-                        {
-                            "path": "core_file_preview_app/user/js/file_preview.js",
-                            "is_raw": False,
-                        }
-                    ]
-                )
-                assets["css"].append("core_file_preview_app/user/css/file_preview.css")
-                modals.append("core_file_preview_app/user/file_preview_modal.html")
-
-            if (
-                "core_linked_records_app" in INSTALLED_APPS
-                and not self.is_administration()
-            ):
-                context["share_pid_button"] = True
-                assets["js"].extend(
-                    [
-                        {
-                            "path": "core_main_app/user/js/sharing_modal.js",
-                            "is_raw": False,
-                        },
-                        {
-                            "path": "core_linked_records_app/user/js/sharing/data_detail.js",
-                            "is_raw": False,
-                        },
-                    ]
-                )
-                modals.append(
-                    "core_linked_records_app/user/sharing/data_detail/modal.html"
-                )
-
-            return self.common_render(
-                request, self.template, context=context, assets=assets, modals=modals
+            return data_view_builder.render_page(
+                request, self.common_render, page_context
             )
         except exceptions.DoesNotExist:
             error_message = "Data not found"
@@ -268,8 +226,7 @@ class ViewData(CommonView):
 
 
 class XSLTView(View):
-    """XSLT view.
-    """
+    """XSLT view."""
 
     @staticmethod
     def get(request, *args, **kwargs):
@@ -319,8 +276,7 @@ def read_xsd_file(xsd_file):
 
 
 class UploadXSLTView(View):
-    """Upload XSLT view.
-    """
+    """Upload XSLT view."""
 
     form_class = UploadXSLTForm
     template_name = "core_main_app/common/xslt/upload.html"
@@ -373,8 +329,7 @@ class UploadXSLTView(View):
 
 
 class TemplateXSLRenderingView(View):
-    """Template XSL rendering view.
-    """
+    """Template XSL rendering view."""
 
     rendering = render
     save_redirect = "core_main_app_manage_template_versions"
@@ -385,7 +340,7 @@ class TemplateXSLRenderingView(View):
     assets = {}
 
     def get(self, request, *args, **kwargs):
-        """ GET request. Create/Show the form for the configuration.
+        """GET request. Create/Show the form for the configuration.
 
         Args:
             request:
@@ -414,16 +369,32 @@ class TemplateXSLRenderingView(View):
                 "list_xslt": template_xsl_rendering.list_xslt.id
                 if template_xsl_rendering.list_xslt
                 else None,
-                "detail_xslt": template_xsl_rendering.detail_xslt.id
-                if template_xsl_rendering.detail_xslt
+                "default_detail_xslt": template_xsl_rendering.default_detail_xslt.id
+                if template_xsl_rendering.default_detail_xslt
+                else None,
+                "list_detail_xslt": [
+                    xslt.id for xslt in template_xsl_rendering.list_detail_xslt
+                ]
+                if template_xsl_rendering.list_detail_xslt
                 else None,
             }
         except (Exception, exceptions.DoesNotExist):
             # If no configuration, new form with pre-selected fields.
-            data = {"template": template.id, "list_xslt": None, "detail_xslt": None}
+            data = {
+                "template": template.id,
+                "list_xslt": None,
+                "default_detail_xslt": None,
+                "list_detail_xslt": None,
+            }
 
         self.assets = {
             "css": ["core_main_app/admin/css/templates_xslt/form.css"],
+            "js": [
+                {
+                    "path": "core_main_app/admin/js/templates_xslt/detail_xslt.js",
+                    "is_raw": False,
+                }
+            ],
         }
 
         self.context = {
@@ -440,7 +411,7 @@ class TemplateXSLRenderingView(View):
         )
 
     def post(self, request, *args, **kwargs):
-        """ POST request. Try to save the configuration.
+        """POST request. Try to save the configuration.
 
         Args:
             request:
@@ -474,19 +445,29 @@ class TemplateXSLRenderingView(View):
                 )
             except (Exception, exceptions.DoesNotExist):
                 list_xslt = None
-            # Get the detail xslt instance
+
+            # Get the list detail xslt instance
             try:
-                detail_xslt = xslt_transformation_api.get_by_id(
-                    request.POST.get("detail_xslt")
+                list_detail_xslt = xslt_transformation_api.get_by_id_list(
+                    request.POST.getlist("list_detail_xslt")
                 )
             except (Exception, exceptions.DoesNotExist):
-                detail_xslt = None
+                list_detail_xslt = None
+
+            # Get the default detail xslt instance
+            try:
+                default_detail_xslt = xslt_transformation_api.get_by_id(
+                    request.POST.get("default_detail_xslt")
+                )
+            except (Exception, exceptions.DoesNotExist):
+                default_detail_xslt = None
 
             template_xsl_rendering_api.add_or_delete(
                 template_xsl_rendering_id=request.POST.get("id"),
                 template_id=request.POST.get("template"),
                 list_xslt=list_xslt,
-                detail_xslt=detail_xslt,
+                default_detail_xslt=default_detail_xslt,
+                list_detail_xslt=list_detail_xslt,
             )
 
             template = template_api.get(request.POST.get("template"))
@@ -501,7 +482,7 @@ class TemplateXSLRenderingView(View):
 
 
 def defender_error_page(request):
-    """ Error page for defender package.
+    """Error page for defender package.
 
     Args:
         request:
