@@ -5,14 +5,13 @@ from core_main_app.utils.integration_tests.fixture_interface import FixtureInter
 
 
 class XslTransformationFixtures(FixtureInterface):
-    """ Xsl Transformation fixtures
-    """
+    """Xsl Transformation fixtures"""
 
     data_1 = None
     data_collection = None
 
     def insert_data(self):
-        """ Insert a set of Data.
+        """Insert a set of Data.
 
         Returns:
 
@@ -21,7 +20,7 @@ class XslTransformationFixtures(FixtureInterface):
         self.generate_data_collection()
 
     def generate_data_collection(self):
-        """ Generate a Data collection.
+        """Generate a Data collection.
 
         Returns:
 
